Enter your API key for the selected Oni provider here.

To obtain your API key, do the following:
1. Visit the provider portal by clicking the "Visit provider portal" button
2. If not logged in, login using the button in the top right
3. If logged in, navigate to the 'User Information' page
4. Under 'User Details' > 'API Key', click "Generate"
5. Copy the API Key shown. Navigate back to this tool and paste in the field provided